@@ -10,6 +10,7 @@ import os
 import json
 
 # hwrt modules
+import hwrt
 import hwrt.utils as utils
 
 
@@ -79,7 +80,7 @@ def worker():
         return get_json_result(results, n=10)
     else:
         # Page where the user can enter a recording
-        return "Classification Worker (Version TODO)"
+        return "Classification Worker (Version %s)" % hwrt.__version__
 
 
 def get_parser():
